stm32-metapac

Crates

git

Versions

stm32u575ai

Flavors

Sadsdlvr

Struct Sadsdlvr 

#[repr(transparent)]
pub struct Sadsdlvr(pub u32);
ADF SAD sound level register.

Tuple Fields

0: u32

Implementations



impl Sadsdlvr

pub const fn sdlvl(&self) -> u16

Short term sound level. This bitfield is set by hardware. It contains the latest sound level computed by the SAD. To refresh this value, SDLVLF must be cleared.

pub const fn set_sdlvl(&mut self, val: u16)

Short term sound level. This bitfield is set by hardware. It contains the latest sound level computed by the SAD. To refresh this value, SDLVLF must be cleared.